@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: shake
 version: 0.15.5
-id: shake-0.15.5-c1ff3657f97a9845a67b0b079af7d6c5
-key: shake_KPhcphcfjx2DjyTHmYKUGr
+id: shake-0.15.5-47395b809e3caeda7a5f7c268b02d6bc
+key: shake_1SB55l08Kut4j6TyxgsabX
 license: BSD3
 copyright: Neil Mitchell 2011-2015
 maintainer: Neil Mitchell <ndmitchell@gmail.com>
@@ -59,7 +59,7 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/shake-0.15.5
 library-dirs: /usr/lib/ghc-7.10.3/site-local/shake-0.15.5
 data-dir: /usr/share/arm-linux-ghc-7.10.3/shake-0.15.5
-hs-libraries: HSshake-0.15.5-KPhcphcfjx2DjyTHmYKUGr
+hs-libraries: HSshake-0.15.5-1SB55l08Kut4j6TyxgsabX
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
@@ -70,7 +70,7 @@ depends:
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     hashable-1.2.4.0-f83fcc5c92d0a1ea59927aca6baa3161
     js-flot-0.8.3-f4527abded51f454b66546bc733ec63f
-    js-jquery-1.12.0-2b122a7f3d637a79036d56af43463e6d
+    js-jquery-1.12.1-cb4fee5dc2f301f8b48d430c321cbb84
     old-time-1.1.0.3-91625432bd7c61d043f9b743fb82dcf7
     process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
     random-1.1-41a0a7ecd483c665a5c3a093a5be2968
